
/*
  ## Cypress FX3 Camera Kit source file (sensor.c)
  ## ===========================
  ##
  ##  Copyright Cypress Semiconductor Corporation, 2010-2012,
  ##  All Rights Reserved
  ##  UNPUBLISHED, LICENSED SOFTWARE.
  ##
  ##  CONFIDENTIAL AND PROPRIETARY INFORMATION
  ##  WHICH IS THE PROPERTY OF CYPRESS.
  ##
  ##  Use of this file is governed
  ##  by the license agreement included in the file
  ##
  ##     <install>/license/license.txt
  ##
  ##  where <install> is the Cypress software
  ##  installation root directory path.
  ##
  ## ===========================
*/

/*
 * This file defines the parameters and the interface for the camera10 image
 * sensor board: SerDes (MAX9706/MAX9705) and Onsemi AP0202/AR0231 image sensor.
 */

#ifndef _INCLUDED_SENSOR_H_
#define _INCLUDED_SENSOR_H_

#include <cyu3types.h>
#include "../../include/wr_cam10_def.h"

#define I2C_DELAY_US 20

/* I2C Slave addresses */
#define CAM_ADDR_WR 0x20
#define CAM_ADDR_RD 0x21
#define ISP_ADDR_WR 0x90
#define ISP_ADDR_RD 0x91
#define DES_ADDR_WR_DEFAULT 0xFC
#define DES_ADDR_WR 0x94
#define DES_ADDR_RD 0x95
#define SER_ADDR_WR 0x80
#define SER_ADDR_RD 0x81

#define SENSOR_REG_WAIT_MS 200
#define SENSOR_REG_RETRY_STEP 4  // 4ms

#define I2C_SLAVEADDR_MASK 0xFE         /* Mask to get actual I2C slave address value without direction bit. */

#define I2C_MEMORY_ADDR_WR 0xA0         /* I2C slave address used to write to an EEPROM. */
#define I2C_MEMORY_ADDR_RD 0xA1         /* I2C slave address used to read from an EEPROM. */

/* GPIO 22 on FX3 is used to reset the Image sensor. */
#define SENSOR_RESET_GPIO 22

extern void SensorInit(void);
extern void SensorReset(void);
extern int I2cWrite8(uint8_t slaveId, uint8_t addr, uint8_t data);
extern int I2cRead8(uint8_t slaveId, uint8_t addr, uint8_t *datap);
extern int I2cWrite16(uint8_t slaveId, uint16_t addr, uint16_t data);
extern int I2cRead16(uint8_t slaveId, uint16_t addr, uint16_t *datap);
extern int I2cWrite16_data8(uint8_t slaveId, uint16_t addr, uint8_t data);
extern int I2cRead16_data8(uint8_t slaveId, uint16_t addr, uint8_t *datap);
extern int SensorWrite16(uint16_t addr, uint16_t data);
extern int SensorRead16(uint16_t addr, uint16_t *datap);

#endif /* _INCLUDED_SENSOR_H_ */
